==> barcode_scanner-3.0.1-beta1.tar.gz: lib/scanbot_sdk_models.dart <==
import 'package:barcode_scanner/sdk_utils.dart';
import 'package:json_annotation/json_annotation.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot Barcode SDK initialization config parameters.
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String? licenseKey;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool? loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String? storageBaseDirectory;

  /// Configuration object that helps to enable encryption inside sdk storage
  EncryptionParameters? encryptionParameters;

  ScanbotSdkConfig(
      {this.licenseKey,
      this.loggingEnabled,
      this.encryptionParameters,
      this.storageBaseDirectory});

  factory ScanbotSdkConfig.fromJson(Map<String, dynamic> json) =>
      _$ScanbotSdkConfigFromJson(json);

  Map<String, dynamic> toJson() => _$ScanbotSdkConfigToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class EncryptionParameters {
  /// A secure password or passphrase to derive the AES key for encryption/decryption
  String password;

  /// Length of the key in AES encryption - 128 or 256 bits
  FileEncryptionMode mode;

  EncryptionParameters(
      {this.password = '', this.mode = FileEncryptionMode.AES256});

  factory EncryptionParameters.fromJson(Map<String, dynamic> json) =>
      _$EncryptionParametersFromJson(json);

  Map<String, dynamic> toJson() => _$EncryptionParametersToJson(this);
}

enum FileEncryptionMode { AES128, AES256 }

/// Scanbot SDK license status.
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;
  Status? status;
  @JsonKey(fromJson: dateFromString)
  DateTime? expirationDate;

  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}

enum Status {
  StatusOkay,
  StatusTrial,
  StatusFailureNotSet,
  StatusFailureCorrupted,
  StatusFailureWrongOS,
  StatusFailureAppIDMismatch,
  StatusFailureExpired
}

==> barcode_scanner-3.0.3-beta1.tar.gz: lib/scanbot_sdk_models.dart <==
import 'package:barcode_scanner/sdk_utils.dart';
import 'package:json_annotation/json_annotation.dart';

part 'scanbot_sdk_models.g.dart';

/// Scanbot Barcode SDK initialization config parameters.
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class ScanbotSdkConfig {
  /// Your license key for the Scanbot SDK.
  String? licenseKey;

  /// Optional logging flag. While it may be useful for development,
  /// consider switching logging OFF in production builds for security and performance reasons!
  bool? loggingEnabled;

  /// Optional custom storage base directory. Can be nil.
  String? storageBaseDirectory;

  /// Configuration object that helps to enable encryption inside sdk storage
  EncryptionParameters? encryptionParameters;

  /// If set to true, Camera X will be used for the RTU-UI components (Android Only) Default is false.
  bool? useCameraX;

  /// If set to false, GPU Acceleration will be disabled for Barcode Scanner, Document Scanner and Generic Document Recognizer (Android Only).
  /// Default is true
  bool? allowGpuAcceleration;

  /// If set to false, disable XNN pack optimizations (Android Only).
  /// Default is true
  bool? allowXnnpackAcceleration;

  ScanbotSdkConfig(
      {this.licenseKey,
      this.loggingEnabled,
      this.encryptionParameters,
      this.storageBaseDirectory,
      this.useCameraX,
      this.allowGpuAcceleration,
      this.allowXnnpackAcceleration});

  factory ScanbotSdkConfig.fromJson(Map<String, dynamic> json) =>
      _$ScanbotSdkConfigFromJson(json);

  Map<String, dynamic> toJson() => _$ScanbotSdkConfigToJson(this);
}

@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class EncryptionParameters {
  /// A secure password or passphrase to derive the AES key for encryption/decryption
  String password;

  /// Length of the key in AES encryption - 128 or 256 bits
  FileEncryptionMode mode;

  EncryptionParameters(
      {this.password = '', this.mode = FileEncryptionMode.AES256});

  factory EncryptionParameters.fromJson(Map<String, dynamic> json) =>
      _$EncryptionParametersFromJson(json);

  Map<String, dynamic> toJson() => _$EncryptionParametersToJson(this);
}

enum FileEncryptionMode { AES128, AES256 }

/// Scanbot SDK license status.
@JsonSerializable(
    createFactory: true, includeIfNull: false, explicitToJson: true)
class SdkLicenseStatus {
  /// Indicates whether the current license key is valid or not.
  bool isLicenseValid;
  Status? status;
  @JsonKey(fromJson: dateFromString)
  DateTime? expirationDate;

  SdkLicenseStatus(this.isLicenseValid);

  factory SdkLicenseStatus.fromJson(Map<String, dynamic> json) =>
      _$SdkLicenseStatusFromJson(json);

  Map<String, dynamic> toJson() => _$SdkLicenseStatusToJson(this);
}

enum Status {
  StatusOkay,
  StatusTrial,
  StatusFailureNotSet,
  StatusFailureCorrupted,
  StatusFailureWrongOS,
  StatusFailureAppIDMismatch,
  StatusFailureExpired
}
